pub struct TaskHandler {
task: Task<()>,
stop_signal: Arc<CondWait>,
cancel_flag: Arc<CondWait>,
}Expand description
TaskHandler
Fields
task: Task<()>stop_signal: Arc<CondWait>Per-task stop signal. Signaling it makes the task stop and run its
callback with Cancelled.
cancel_flag: Arc<CondWait>Set once the task has finished running its callback.
Implementations
Sourceimpl TaskHandler
impl TaskHandler